# ChangeLog


## v1.2.4

* support variables injection on template render()

## v1.2.3

* reload web server when modules in the lib dir are updated

## v1.2.2

* load modules from application lib/ dir

## v1.2.1

* fix get_domain() with localhost (thanks to Oana Apostol for reporting)

## v1.2.0

* added lang support

## v1.1.0

* added support for dbsupport.py within app dir

## v1.0.1

* Update to python3

## v1.0.0
